package com.ruoyi.manage.service;

import java.util.List;
import com.ruoyi.manage.domain.RecordStoreCheck;

/**
 * 盘点记录Service接口
 * 
 * @author wangh
 * @date 2024-01-19
 */
public interface IRecordStoreCheckService 
{
    /**
     * 查询盘点记录
     * 
     * @param checkId 盘点记录主键
     * @return 盘点记录
     */
    public RecordStoreCheck selectRecordStoreCheckByCheckId(Long checkId);

    /**
     * 查询盘点记录列表
     * 
     * @param recordStoreCheck 盘点记录
     * @return 盘点记录集合
     */
    public List<RecordStoreCheck> selectRecordStoreCheckList(RecordStoreCheck recordStoreCheck);

    /**
     * 新增盘点记录
     * 
     * @param recordStoreCheck 盘点记录
     * @return 结果
     */
    public int insertRecordStoreCheck(RecordStoreCheck recordStoreCheck);

    /**
     * 修改盘点记录
     * 
     * @param recordStoreCheck 盘点记录
     * @return 结果
     */
    public int updateRecordStoreCheck(RecordStoreCheck recordStoreCheck);

    /**
     * 批量删除盘点记录
     * 
     * @param checkIds 需要删除的盘点记录主键集合
     * @return 结果
     */
    public int deleteRecordStoreCheckByCheckIds(String checkIds);

    /**
     * 删除盘点记录信息
     * 
     * @param checkId 盘点记录主键
     * @return 结果
     */
    public int deleteRecordStoreCheckByCheckId(Long checkId);
}
